@@ -347,6 +347,11 @@ class DocTestController(SageObject):
                 # Special case to run all optional tests
                 options.optional = True
             else:
+                # Check that all tags are valid
+                for o in options.optional:
+                    if not optionaltag_regex.search(o):
+                        raise ValueError('invalid optional tag {!r}'.format(o))
+
                 options.optional |= auto_optional_tags
 
         self.options = options
