@@ -20,8 +20,8 @@ To list the packages available, either use in a terminal one of ``sage
 command inside Sage::
 
     sage: from sage.misc.package import list_packages
-    sage: pkgs = list_packages(local=True)
-    sage: sorted(pkgs.keys())  # random
+    sage: pkgs = list_packages(local=True)  # optional - build
+    sage: sorted(pkgs.keys())  # optional - build, random
     ['4ti2',
      'alabaster',
      'arb',
@@ -43,7 +43,7 @@ Functions
 # ****************************************************************************
 from __future__ import print_function
 
-from sage.env import SAGE_PKGS
+import sage.env
 
 import json
 import os
@@ -135,12 +135,12 @@ def pip_installed_packages():
     EXAMPLES::
 
         sage: from sage.misc.package import pip_installed_packages
-        sage: d = pip_installed_packages()
-        sage: 'scipy' in d
+        sage: d = pip_installed_packages()  # optional - build
+        sage: 'scipy' in d  # optional - build
         True
-        sage: d['scipy']
+        sage: d['scipy']  # optional - build
         u'...'
-        sage: d['beautifulsoup']   # optional - beautifulsoup
+        sage: d['beautifulsoup']   # optional - build beautifulsoup
         u'...'
     """
     with open(os.devnull, 'w')  as devnull:
@@ -184,29 +184,29 @@ def list_packages(*pkg_types, **opts):
     EXAMPLES::
 
         sage: from sage.misc.package import list_packages
-        sage: L = list_packages('standard')
-        sage: sorted(L.keys())  # random
+        sage: L = list_packages('standard')  # optional - build
+        sage: sorted(L.keys())  # optional - build, random
         ['alabaster',
          'arb',
          'babel',
          ...
          'zn_poly',
          'zope_interface']
-        sage: L['ppl']
+        sage: L['ppl']  # optional - build
         {'installed': True,
          'installed_version': '...',
          'remote_version': '...',
          'type': 'standard'}
 
-        sage: L = list_packages('pip', local=True)
-        sage: L['beautifulsoup']
+        sage: L = list_packages('pip', local=True)  # optional - build
+        sage: L['beautifulsoup']                    # optional - build
         {'installed': ...,
          'installed_version': ...,
          'remote_version': None,
          'type': 'pip'}
 
-        sage: L = list_packages('pip')   # optional - internet
-        sage: L['beautifulsoup']         # optional - internet
+        sage: L = list_packages('pip')   # optional - build internet
+        sage: L['beautifulsoup']         # optional - build internet
         {'installed': ...,
          'installed_version': ...,
          'remote_version': u'...',
@@ -214,7 +214,7 @@ def list_packages(*pkg_types, **opts):
 
     Check the option ``exclude_pip``::
 
-        sage: list_packages('pip', exclude_pip=True)
+        sage: list_packages('pip', exclude_pip=True)  # optional - build
         {}
     """
     if not pkg_types:
@@ -232,6 +232,7 @@ def list_packages(*pkg_types, **opts):
     installed = installed_packages(exclude_pip)
 
     pkgs = {}
+    SAGE_PKGS = sage.env.SAGE_PKGS
     for p in os.listdir(SAGE_PKGS):
         try:
             f = open(os.path.join(SAGE_PKGS, p, "type"))
@@ -279,19 +280,19 @@ def installed_packages(exclude_pip=True):
 
     EXAMPLES::
 
-        sage: installed_packages()
+        sage: installed_packages()  # optional - build
         {...'arb': ...'pynac': ...}
 
     .. SEEALSO::
 
         :func:`sage.misc.package.list_packages`
     """
-    from sage.env import SAGE_SPKG_INST
     installed = {}
     if not exclude_pip:
         installed.update(pip_installed_packages())
     # Sage packages should override pip packages (Trac #23997)
-    installed.update(pkgname_split(pkgname) for pkgname in os.listdir(SAGE_SPKG_INST))
+    installed.update(pkgname_split(pkgname)
+                     for pkgname in os.listdir(sage.env.SAGE_SPKG_INST))
     return installed
 
 
@@ -309,12 +310,12 @@ def is_package_installed(package, exclude_pip=True):
 
     EXAMPLES::
 
-        sage: is_package_installed('pari')
+        sage: is_package_installed('pari')  # optional - build
         True
 
     Giving just the beginning of the package name is not good enough::
 
-        sage: is_package_installed('matplotli')
+        sage: is_package_installed('matplotli')  # optional - build
         False
 
     Otherwise, installing "pillow" would cause this function to think
@@ -323,7 +324,7 @@ def is_package_installed(package, exclude_pip=True):
     Check that the option ``exclude_pip`` is turned on by default::
 
         sage: from sage.misc.package import list_packages
-        sage: for pkg in list_packages('pip', local=True):
+        sage: for pkg in list_packages('pip', local=True):  # optional - build
         ....:     assert not is_package_installed(pkg)
 
     .. NOTE::
@@ -362,10 +363,10 @@ def package_versions(package_type, local=False):
 
     EXAMPLES::
 
-        sage: std = package_versions('standard', local=True)
-        sage: 'gap' in std
+        sage: std = package_versions('standard', local=True)  # optional - build
+        sage: 'gap' in std  # optional - build
         True
-        sage: std['zn_poly']  # random
+        sage: std['zn_poly']  # optional - build, random
         ('0.9.p12', '0.9.p12')
     """
     return {pkg['name']: (pkg['installed_version'], pkg['remote_version']) for pkg in list_packages(package_type, local=local).values()}
@@ -391,14 +392,15 @@ def standard_packages():
     EXAMPLES::
 
         sage: from sage.misc.package import standard_packages
-        sage: installed, not_installed = standard_packages()
-        sage: installed[0], installed[-1]
+        sage: installed, not_installed = standard_packages()  # optional - build
+        sage: installed[0], installed[-1]  # optional - build
         ('alabaster', 'zope_interface')
     """
     pkgs = list_packages('standard', local=True).values()
     return (sorted(pkg['name'] for pkg in pkgs if pkg['installed']),
             sorted(pkg['name'] for pkg in pkgs if not pkg['installed']))
 
+
 def optional_packages():
     """
     Return two lists. The first contains the installed and the second
@@ -419,15 +421,15 @@ def optional_packages():
     EXAMPLES::
 
         sage: from sage.misc.package import optional_packages
-        sage: installed, not_installed = optional_packages()
-        sage: 'ore_algebra' in installed+not_installed
+        sage: installed, not_installed = optional_packages()  # optional - build
+        sage: 'ore_algebra' in installed+not_installed  # optional - build
         True
-        sage: 'beautifulsoup' in installed+not_installed
+        sage: 'beautifulsoup' in installed+not_installed  # optional - build
         True
 
-        sage: 'beautifulsoup' in installed   # optional - beautifulsoup
+        sage: 'beautifulsoup' in installed   # optional - build beautifulsoup
         True
-        sage: 'ore_algebra' in installed     # optional - ore_algebra
+        sage: 'ore_algebra' in installed     # optional - build ore_algebra
         True
     """
     pkgs = list_packages('optional', local=True)
@@ -457,7 +459,7 @@ def experimental_packages():
     EXAMPLES::
 
         sage: from sage.misc.package import experimental_packages
-        sage: installed, not_installed = experimental_packages()
+        sage: installed, not_installed = experimental_packages()  # optional - build
     """
     pkgs = list_packages('experimental', local=True).values()
     return (sorted(pkg['name'] for pkg in pkgs if pkg['installed']),
@@ -479,21 +481,21 @@ def package_manifest(package):
     EXAMPLES::
 
         sage: from sage.misc.package import package_manifest
-        sage: sagetex_manifest = package_manifest('sagetex')
-        sage: sagetex_manifest['package_name'] == 'sagetex'
+        sage: sagetex_manifest = package_manifest('sagetex')  # optional - build
+        sage: sagetex_manifest['package_name'] == 'sagetex'  # optional - build
         True
-        sage: 'files' in sagetex_manifest
+        sage: 'files' in sagetex_manifest  # optional - build
         True
 
     Test a nonexistent package::
 
-        sage: package_manifest('dummy-package')
+        sage: package_manifest('dummy-package')  # optional - build
         Traceback (most recent call last):
         ...
         KeyError: 'dummy-package'
     """
     version = installed_packages()[package]
-    stamp_file = os.path.join(os.environ['SAGE_SPKG_INST'],
+    stamp_file = os.path.join(sage.env.SAGE_SPKG_INST,
                               '{}-{}'.format(package, version))
     with open(stamp_file) as f:
         spkg_meta = json.load(f)
